from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware

from app.api.api_v1.api import api_router
from app.core.config import settings

app = FastAPI(
    title=settings.PROJECT_NAME,
    openapi_url="/openapi.json",
    docs_url="/docs",
    redoc_url="/redoc",
)

# Add CORS middleware
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

app.include_router(api_router, prefix=settings.API_V1_STR)

@app.get("/")
async def root():
    """
    Root endpoint returning basic service information.
    """
    return {
        "title": settings.PROJECT_NAME,
        "description": "Small Business Inventory Management System API",
        "documentation": "/docs",
        "health_check": "/health"
    }

@app.get("/health", status_code=200)
async def health_check():
    """
    Health check endpoint.
    """
    return {"status": "ok"}